@@ -1,9 +1,14 @@
+
+static const char cright_years_z[] =
+
 /* Handle so called `shell archives'.
-   Copyright (C) 1994, 1995, 1996, 2002, 2005 Free Software Foundation, Inc.
+   Copyright (C) */ "1994, 1995, 1996, 2002, 2005, 2006, 2007, 2010";
+
+/* Free Software Foundation, Inc.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2, or (at your option)
+   the Free Software Foundation; either version 3, or (at your option)
    any later version.
 
    This program is distributed in the hope that it will be useful,
@@ -12,30 +17,20 @@
    GNU General Public License for more details.
 
    You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software Foundation,
-   Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+   along with this program; if not, see:  http://www.gnu.org/licenses.
 */
 
-#ifdef HAVE_CONFIG_H
-# include <config.h>
-#endif
-#include "liballoca.h"
+#include "local.h"
 
-#include "system.h"
-#include "basename.h"
-#include "error.h"
-#include "exit.h"
+#include "liballoca.h"
 #include "xalloc.h"
 #include "xgetcwd.h"
-
 #include "scripts.x"
 
 #if HAVE_LOCALE_H
-# include <locale.h>
 #else
 # define setlocale(Category, Locale)
 #endif
-#include "gettext.h"
 
 /*
  *  _() and N_() strings are both extracted into the .pot file.
@@ -94,6 +89,32 @@ struct tm *localtime ();
 # include <limits.h>
 #endif
 
+#if !NO_WALKTREE
+
+/* Declare directory reading routines and structures.  */
+
+#ifdef __MSDOS__
+# include "msd_dir.h"
+#else
+# include DIRENT_HEADER
+#endif
+
+#if HAVE_DIRENT_H
+# define NAMLEN(dirent) (strlen((dirent)->d_name))
+#else
+# define NAMLEN(dirent) ((dirent)->d_namlen)
+# ifndef __MSDOS__
+#  define dirent direct
+# endif
+#endif
+
+#endif /* !NO_WALKTREE */
+
+/* Option variables.  */
+
+#include "inttostr.h"
+#include "md5.h"
+
 /* Determine whether an integer type is signed, and its bounds.
    This code assumes two's (or one's!) complement with no holes.  */
 
@@ -111,42 +132,8 @@ struct tm *localtime ();
 # define TYPE_MAXIMUM(t) ((t) (~ (t) 0 - TYPE_MINIMUM (t)))
 #endif
 
-#if !NO_WALKTREE
-
-/* Declare directory reading routines and structures.  */
-
-#ifdef __MSDOS__
-# include "msd_dir.h"
-# define NAMLEN(dirent) ((dirent)->d_namlen)
-#else
-# if HAVE_DIRENT_H
-#  include <dirent.h>
-#  define NAMLEN(dirent) (strlen((dirent)->d_name))
-# else
-#  define dirent direct
-#  define NAMLEN(dirent) ((dirent)->d_namlen)
-#  if HAVE_SYS_NDIR_H
-#   include <sys/ndir.h>
-#  endif
-#  if HAVE_SYS_DIR_H
-#   include <sys/dir.h>
-#  endif
-#  if HAVE_NDIR_H
-#   include <ndir.h>
-#  endif
-# endif
-#endif
-
-DIR *opendir ();
-struct dirent *readdir ();
-
-#endif /* !NO_WALKTREE */
-
-/* Option variables.  */
-
-#include "getopt.h"
-#include "inttostr.h"
-#include "md5.h"
+#include "whoami.c"
+#include "md5.c"
 
 /* No Brown-Shirt mode.  */
 static int vanilla_operation_mode = 0;
@@ -187,10 +174,10 @@ static int md5_count_mode = 1;
 static int inhibit_piping_mode = 0;
 
 /* --no-i18n option to prevent internationalized shell archives.  */
-static int no_i18n;
+static int no_i18n = 0;
 
 /* Character to get at the beginning of each line.  */
-static int line_prefix;
+static int line_prefix = '\0';
 
 /* Option to generate "Archive-name:" headers.  */
 static int net_headers_mode = 0;
@@ -208,7 +195,7 @@ static int quiet_unshar_mode = 0;
 static const char *here_delimiter = DEFAULT_HERE_DELIMITER;
 
 /* Value of strlen (here_delimiter).  */
-static size_t here_delimiter_length;
+static size_t here_delimiter_length = 0;
 
 /* Use line_prefix even when first char does not force it.  */
 static int mandatory_prefix_mode = 0;
@@ -254,10 +241,10 @@ static int show_version = 0;
 static FILE *output = NULL;
 
 /* Position for archive type message.  */
-static off_t archive_type_position;
+static off_t archive_type_position = 0;
 
 /* Position for first file in the shar file.  */
-static off_t first_file_position;
+static off_t first_file_position = 0;
 
 /* Base for output filename.  */
 static char *output_base_name = NULL;
@@ -277,14 +264,14 @@ static unsigned char byte_is_binary[256];
 static struct stat struct_stat;
 
 /* Nonzero if special NLS option (--print-text-domain-dir) is selected.  */
-static int print_text_dom_dir;
+static int print_text_dom_dir = 0;
 
 /* The number used to make the intermediate files unique.  */
-static int sharpid;
+static int sharpid = 0;
 
 /* scribble space. */
 static size_t scribble_size = 1024 + (BUFSIZ * 2);
-static char* scribble;
+static char* scribble = NULL;
 
 static int translate_script = 0;
 
@@ -649,9 +636,8 @@ Note: not verifying md5sums.  Consider installing GNU coreutils."));
   if (timestamp_mode)
     {
       fprintf (output, timestamp_z, N_("\
-WARNING: not restoring timestamps.  Consider getting and"),
-	       N_("\
-installing GNU `touch'\\'', distributed in GNU File Utilities..."));
+WARNING: not restoring timestamps.  Consider getting and\n\
+installing GNU `touch'\\'', distributed in GNU coreutils..."));
     }
 
   if (file_size_limit == 0 || part_number == 1)
@@ -1025,7 +1011,7 @@ change_files (const char *restore_name, off_t remaining_size)
     char *nm = archive_name ? archive_name : "a multipart";
     char *pz = xmalloc (sizeof(part_z) + strlen(nm) + 16);
     sprintf (pz, part_z, part_number, nm);
-    fprintf (output, file_leader_z, pz, "", sharpid);
+    fprintf (output, file_leader_z, pz, "", PACKAGE, VERSION, sharpid);
     free (pz);
   }
 
@@ -1959,12 +1945,12 @@ main (argc, argv)
   textdomain (PACKAGE);
 
   while (optchar = getopt_long (argc, argv,
-				"+$BCDFL:MPQSTVXZab:cd:fg:hjl:mn:o:pqs:wxz",
+				"+$BDFL:MPQSTVXZab:cd:fg:hjl:mn:o:pqs:wxz",
 				long_options, NULL),
 	 optchar != EOF)
     switch (optchar)
       {
-      case NUL:
+      case 0: case 1: /* handled by getopt_long() */
 	break;
 
       case '$':
@@ -2031,14 +2017,11 @@ main (argc, argv)
 	bits_per_compressed_byte = atoi (optarg);
 	/* Fall through.  */
 
-      case 'C':
       case 'Z':
 #ifndef HAVE_COMPRESS
 	error (EXIT_FAILURE, 0, _("\
 This system doesn't support -Z ('compress'), use -z instead"));
 #endif
-	if (optchar == 'C')
-	  error (0, 0, _("-C is being deprecated, use -Z instead"));
 	set_file_mode ('Z');
 	break;
 
@@ -2135,7 +2118,7 @@ This system doesn't support -Z ('compress'), use -z instead"));
 This is free software; see the source for copying conditions.  There is NO\n\
 warranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.\n\
 "),
-	      "1994, 1995, 1996, 2004, 2005");
+	      cright_years_z);
       exit (EXIT_SUCCESS);
     }
 
@@ -2201,8 +2184,10 @@ warranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.\n\
   if (!submitter_address)
     submitter_address = get_submitter (NULL);
 
-  if (!output)
+  if (output == NULL)
     output = stdout;
+  if (isatty (fileno (output)) && isatty (STDERR_FILENO))
+    freopen ("/dev/null", "w", stderr);
 
   /* Maybe prepare to decide dynamically about file type.  */
 
